@@ -8,6 +8,10 @@ from typing import Any, IO
 from dimtim.utils import duration, timezone
 from dimtim.utils.serializable import Serializable
 
+__all__ = [
+    'dump', 'dumps', 'load', 'loads', 'JSONEncoder', 'JSONDecoder', 'JSONDecodeError'
+]
+
 compat_transforms = {}
 
 try:
@@ -70,7 +74,7 @@ def load(fp: IO, **kwargs) -> None:
     return json.load(fp, **kwargs)
 
 
-def loads(data: str, **kwargs) -> str:
+def loads(data: str, **kwargs) -> Any:
     return json.loads(data, **kwargs)
 
 
